@@ -1,3 +1,6 @@
+/* This is an experimental fork of GNU GSEGrafix.  It is NOT the original work
+   which can be found at http://www.gnu.org/software/gsegrafix */
+
 /*
   This file is part of GSEGrafix, a scientific and engineering plotting 
   program.
@@ -19,4 +22,5 @@
 */
 struct gse_ctx;
 struct data_parser;
-void     CheckParamData (struct gse_ctx *, struct data_parser *);
+#include "glib.h"
+gboolean CheckParamData (struct gse_ctx *, struct data_parser *, GError **err);
