@@ -1,3 +1,6 @@
+/* This is an experimental fork of GNU GSEGrafix.  It is NOT the original work
+   which can be found at http://www.gnu.org/software/gsegrafix */
+
 /*
   This file is part of GSEGrafix, a scientific and engineering plotting 
   program.
@@ -18,8 +21,8 @@
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 /* Clip.c */
-int      Clip2d ( double xmin, double xmax, double ymin, double ymax, double *line_coords );
-int      ClipPolar ( double rmin, double rmax, double *line_coords );
-int      Clip3d ( double xmin, double xmax, double ymin, double ymax, double zmin, double zmax,
-                  double *line_coords );
+int Clip2d (const double *lower, const double *upper, double *line_coords);
+int Clip3d (const double *lower, const double *upper, double *line_coords);
+int ClipPolar ( double rmin, double rmax, double *line_coords );
+
 
