@@ -1,3 +1,6 @@
+/* This is an experimental fork of GNU GSEGrafix.  It is NOT the original work
+   which can be found at http://www.gnu.org/software/gsegrafix */
+
 /*
   This file is part of GSEGrafix, a scientific and engineering plotting 
   program.
@@ -18,6 +21,7 @@
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 struct gse_ctx;
-void     ContourPlot2d (struct gse_ctx *context, int iplot, int icontour, int xindex, int yindex, int zindex, int nx, int ny );
+struct target;
+void     ContourPlot2d (struct target *, const struct gse_ctx *context, int iplot, int icontour, int nx, int ny );
 
 
