@@ -1,3 +1,6 @@
+/* This is an experimental fork of GNU GSEGrafix.  It is NOT the original work
+   which can be found at http://www.gnu.org/software/gsegrafix */
+
 /*
   This file is part of GSEGrafix, a scientific and engineering plotting 
   program.
@@ -19,3 +22,7 @@
 */
 struct gse_ctx;
 void     DataMinMax (struct gse_ctx *context);
+
+
+
+
