@@ -1,3 +1,6 @@
+/* This is an experimental fork of GNU GSEGrafix.  It is NOT the original work
+   which can be found at http://www.gnu.org/software/gsegrafix */
+
 /*
   This file is part of GSEGrafix, a scientific and engineering plotting 
   program.
@@ -18,7 +21,18 @@
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 struct gse_ctx;
-void     DrawAxisLabels (struct gse_ctx *);
+
+struct tick_label_widths
+{
+  double width_ytick_labels;
+  double width_axis1_tick_labels;
+  double width_axis2_tick_labels;
+  double width_axis3_tick_labels;
+};
+
+struct target;
+
+void DrawAxisLabels (struct target *, const struct gse_ctx *, const struct tick_label_widths *);
 
 
 
