@@ -1,3 +1,6 @@
+/* This is an experimental fork of GNU GSEGrafix.  It is NOT the original work
+   which can be found at http://www.gnu.org/software/gsegrafix */
+
 /*
   This file is part of GSEGrafix, a scientific and engineering plotting 
   program.
@@ -18,4 +21,6 @@
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 struct gse_ctx;
-void     DrawBackgroundImage (struct gse_ctx *context);
+#include <glib.h>
+struct target;
+gboolean DrawBackgroundImage (struct target *target, const struct gse_ctx *context, GError **err);
