@@ -1,3 +1,6 @@
+/* This is an experimental fork of GNU GSEGrafix.  It is NOT the original work
+   which can be found at http://www.gnu.org/software/gsegrafix */
+
 /*
   This file is part of GSEGrafix, a scientific and engineering plotting 
   program.
@@ -18,7 +21,8 @@
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 struct gse_ctx;
-void     DrawGrid (struct gse_ctx *context, char *axis_type,
+struct target;
+void     DrawGrid (struct target *, const struct gse_ctx *context, char *axis_type,
                     double x11_screen, double y11_screen, double x12_screen, double y12_screen,
-                    double x21_screen, double y21_screen, int nticks, double *tick_values,
+                    double x21_screen, double y21_screen, int nticks, const double *tick_values,
                     double offset1, double offset2 );
