@@ -1,3 +1,6 @@
+/* This is an experimental fork of GNU GSEGrafix.  It is NOT the original work
+   which can be found at http://www.gnu.org/software/gsegrafix */
+
 /*
   This file is part of GSEGrafix, a scientific and engineering plotting 
   program.
@@ -17,6 +20,8 @@
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
-struct gse_ctx;
-void     DrawText (struct gse_ctx *);
+#include "gsegraf.h"
+void     DrawText (struct target *, const struct gse_ctx *);
+void background_text (struct target *target, const struct gse_ctx *context, const char *text_str,
+		      double x1, double y1, enum GseAnchorType anthor);
 
