@@ -1,3 +1,6 @@
+/* This is an experimental fork of GNU GSEGrafix.  It is NOT the original work
+   which can be found at http://www.gnu.org/software/gsegrafix */
+
 /*
   This file is part of GSEGrafix, a scientific and engineering plotting 
   program.
@@ -18,8 +21,9 @@
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 struct gse_ctx;
-void     DrawTickMarks (struct gse_ctx *context, char *axis_type, int minor_ticks_flag, int center_flag,
-                         double x1_screen, double y1_screen, double x2_screen, double y2_screen,
-                         int nticks, double *tick_values, double offset1, double offset2,
-                         double tick_angle );
+struct target;
+void DrawTickMarks (struct target *target, const struct gse_ctx *context, const char *axis_type, int minor_ticks_flag, int center_flag,
+		    double x1_screen, double y1_screen, double x2_screen, double y2_screen,
+		    int nticks, const double *tick_values, double offset1, double offset2,
+		    double tick_angle );
 
