@@ -1,3 +1,6 @@
+/* This is an experimental fork of GNU GSEGrafix.  It is NOT the original work
+   which can be found at http://www.gnu.org/software/gsegrafix */
+
 /*
   This file is part of GSEGrafix, a scientific and engineering plotting 
   program.
@@ -18,5 +21,7 @@
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 struct gse_ctx;
-void DrawTickMarks3d (struct gse_ctx *context);
+struct tick_label_widths;
+struct target;
+void DrawTickMarks3d (struct target *, const struct gse_ctx *context, struct tick_label_widths *tlw);
 
