@@ -1,3 +1,6 @@
+/* This is an experimental fork of GNU GSEGrafix.  It is NOT the original work
+   which can be found at http://www.gnu.org/software/gsegrafix */
+
 /*
   This file is part of GSEGrafix, a scientific and engineering plotting 
   program.
@@ -18,7 +21,9 @@
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 /* FileRead.c */
+#include <glib.h>
 struct gse_ctx;
 struct data_parser;
-void     FileRead (struct gse_ctx *, struct data_parser *);
+gboolean FileRead (struct gse_ctx *context, struct data_parser *parser, GError **err);
+
 
