@@ -1,3 +1,6 @@
+/* This is an experimental fork of GNU GSEGrafix.  It is NOT the original work
+   which can be found at http://www.gnu.org/software/gsegrafix */
+
 /*
   This file is part of GSEGrafix, a scientific and engineering plotting 
   program.
@@ -18,4 +21,5 @@
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 struct gse_ctx;
-void GetWindowCoords (struct gse_ctx *context, double *plot_coords, double *window_coords );
+struct target;
+void GetWindowCoords (const struct target *, const struct gse_ctx *context, double *plot_coords, double *window_coords );
