@@ -1,3 +1,6 @@
+/* This is an experimental fork of GNU GSEGrafix.  It is NOT the original work
+   which can be found at http://www.gnu.org/software/gsegrafix */
+
 /*
   This file is part of GSEGrafix, a scientific and engineering plotting 
   program.
@@ -18,6 +21,8 @@
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 struct gse_ctx;
-void HistogramCalculate (struct gse_ctx *context, int iplot);
-void PlotHistogram (struct gse_ctx *context, int iplot);
+struct plot_parameters;
+struct target;
+void HistogramCalculate (struct gse_ctx *context, struct plot_parameters *);
+void PlotHistogram (struct target *, const struct gse_ctx *context, int iplot);
 
