@@ -1,3 +1,6 @@
+/* This is an experimental fork of GNU GSEGrafix.  It is NOT the original work
+   which can be found at http://www.gnu.org/software/gsegrafix */
+
 /*
   This file is part of GSEGrafix, a scientific and engineering plotting 
   program.
@@ -18,5 +21,7 @@
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 struct gse_ctx;
-void     Initialize3d (struct gse_ctx *);
+struct target;
+void Initialize3d (const struct target *target, struct gse_ctx *context);
+void get_origin (const struct gse_ctx *context, int quadrant, double *origin);
 
