@@ -1,3 +1,6 @@
+/* This is an experimental fork of GNU GSEGrafix.  It is NOT the original work
+   which can be found at http://www.gnu.org/software/gsegrafix */
+
 /*
   This file is part of GSEGrafix, a scientific and engineering plotting 
   program.
@@ -18,32 +21,35 @@
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
+#ifndef INITIALIZE_PLOT
+#define INITIALIZE_PLOT
+
 #include <stdbool.h>
+#include <glib.h>
+#include <cairo.h>
 
 struct gse_ctx;
-
+struct target;
 
 struct data_parser
 {
-  /* A scanf format string to parse numeric data */
-  char  *formats;
+  GQuark domain;
 
-  /* A scanf format string to parse modifiers (typicaly asterisks) */
-  char  *formats_mod;
+  int maxline;
+  char *line;
+  char *string_get;
+  char *param_file;
 
-  int *nformats;
-
-  char *filenames;
-
-  int *nfilenames;
-
-  char *save_filename;
   bool close_after_save;
+  char *save_filename;
+  
+  int window_width;
+  int window_height;
 };
 
-void     InitializePlot (struct gse_ctx *);
-void PlotBox (struct gse_ctx *context);
 
-
+void get_box_from_coords (const struct gse_ctx *context, double width, double height, cairo_rectangle_t *rect);
+void get_box (const struct target *, const struct gse_ctx *context, cairo_rectangle_t *rect);
 
 
+#endif
