@@ -1,3 +1,6 @@
+/* This is an experimental fork of GNU GSEGrafix.  It is NOT the original work
+   which can be found at http://www.gnu.org/software/gsegrafix */
+
 /*
   This file is part of GSEGrafix, a scientific and engineering plotting 
   program.
@@ -19,9 +22,10 @@
 */
 #include <glib.h>
 struct gse_ctx;
-void     PlotInterp3d (struct gse_ctx *, int iplot,
+struct target;
+void     PlotInterp3d (struct target *, const struct gse_ctx *, int iplot,
                         double xmin, double ymin, double zmin, double zmax,
                         double xscale, double yscale, double zscale,
-                        double *origin, double *Ryz, guint32 *fill_color,
-                        double *xpoints, double *ypoints, double *zpoints );
+		       const double *origin, const double *Ryz, const guint32 *fill_color,
+		       const double *xpoints, const double *ypoints, const double *zpoints );
 
