@@ -1,3 +1,6 @@
+/* This is an experimental fork of GNU GSEGrafix.  It is NOT the original work
+   which can be found at http://www.gnu.org/software/gsegrafix */
+
 /*
   This file is part of GSEGrafix, a scientific and engineering plotting 
   program.
@@ -19,8 +22,9 @@
 */
 #include <glib.h>
 struct gse_ctx;
-void     PlotNormal3d (struct gse_ctx *, int iplot,
-                        double xmin, double ymin, double zmin, double zmax,
-                        double xscale, double yscale, double zscale,
-                        double *origin, double *Ryz, guint32 *fill_color,
-                        double *xpoints, double *ypoints, double *zpoints );
+struct target;
+void     PlotNormal3d (struct target *, const struct gse_ctx *, int iplot,
+		       double xmin, double ymin, double zmin, double zmax,
+		       double xscale, double yscale, double zscale,
+		       const double *origin, const double *Ryz, const guint32 *fill_color,
+		       double *xpoints, double *ypoints, double *zpoints );
