@@ -1,3 +1,6 @@
+/* This is an experimental fork of GNU GSEGrafix.  It is NOT the original work
+   which can be found at http://www.gnu.org/software/gsegrafix */
+
 /*
   This file is part of GSEGrafix, a scientific and engineering plotting 
   program.
@@ -17,8 +20,13 @@
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
-#include <glib.h>
 /* PolarPlot.c */
 struct gse_ctx;
-void PolarPlot (struct gse_ctx *context);
+struct target;
+void PolarPlot (struct target *, struct gse_ctx *context);
 
+void polar_get_geometry (const struct target *,
+			 double *xorigin, double *yorigin, double *radius);
+
+void polar_get_geometry_from_coords (double window_width, double window_height,
+				     double *xorigin, double *yorigin, double *radius);
