@@ -1,3 +1,6 @@
+/* This is an experimental fork of GNU GSEGrafix.  It is NOT the original work
+   which can be found at http://www.gnu.org/software/gsegrafix */
+
 /*
   This file is part of GSEGrafix, a scientific and engineering plotting 
   program.
@@ -19,4 +22,9 @@
 */
 struct gse_ctx;
 struct data_parser;
-void     ReadParamFile (struct gse_ctx *, struct data_parser *);
+#include "gsegraf.h"
+#include "InitializePlot.h"
+gboolean ReadParamFile (struct gse_ctx *, struct data_parser *, GError **err);
+enum GseAnchorType anchor_from_string (const char *str);
+
+enum line_texture char_to_texture (char c);
