@@ -1,3 +1,6 @@
+/* This is an experimental fork of GNU GSEGrafix.  It is NOT the original work
+   which can be found at http://www.gnu.org/software/gsegrafix */
+
 /*
   This file is part of GSEGrafix, a scientific and engineering plotting 
   program.
@@ -17,5 +20,12 @@
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
+#include <glib.h>
+
 struct gse_ctx;
-void ZoomIn (struct gse_ctx *context, double x1_window, double y1_window, double x2_window, double y2_window );
+struct tick_labels;
+gboolean ZoomIn (struct gse_ctx *context,
+		 double width, double height,
+		 double x1_window, double y1_window,
+		 double x2_window, double y2_window,
+		 struct tick_labels *original_tick_labels);
